import unittest

import vdcpy.work as vdc_work
import vdcpy.user as vdc_user
import vdcpy.link as vdc_link
import tests.utils.project_util as project_util
import tests.utils.user_util as user_util
import tests.utils.work_util as work_util
import tests.utils.link_util as link_util


class AddLinkTest(unittest.TestCase):

    def setUp(self):
        # In case of flies...
        project_util.delete_unittest_project()
        user_util.delete_unittest_users()

        user_util.add_unittest_user()
        project_util.add_unittest_project()
        work_util.add_unittest_work()

    def test_successful_add_link(self):
        # Get unittest work id
        work_list = vdc_work.get_works(title='unittest_work')
        work_id = work_list[0]['id']
        # Get unittest user id
        user_list = vdc_user.get_users(name='unittest_user')
        user_id = user_list[0]['id']

        link_info = {
            'link': 'unittest_link',
            'name': 'unittest_name',
            'visibility': 'open',
            'work': work_id,
            'created_by': user_id
        }
        new_link = vdc_link.add_link(link_info)
        self.assertEqual(type(new_link), dict)

    def test_fail_add_link_no_link(self):
        # Get unittest work id
        work_list = vdc_work.get_works(title='unittest_work')
        work_id = work_list[0]['id']
        # Get unittest user id
        user_list = vdc_user.get_users(name='unittest_user')
        user_id = user_list[0]['id']

        link_info = {
            # 'link': 'unittest_link',
            'name': 'unittest_name',
            'visibility': 'open',
            'work': work_id,
            'created_by': user_id
        }
        try:
            new_link = vdc_link.add_link(link_info)
            self.assertEqual(new_link, 'You are not here')
        except Exception as e:
            self.assertEqual(
                str(e),
                "Error adding work: 400 - {'message': 'Link is required.'}")

    def test_fail_add_link_no_name(self):
        # Get unittest work id
        work_list = vdc_work.get_works(title='unittest_work')
        work_id = work_list[0]['id']
        # Get unittest user id
        user_list = vdc_user.get_users(name='unittest_user')
        user_id = user_list[0]['id']

        link_info = {
            'link': 'unittest_link',
            # 'name': 'unittest_name',
            'visibility': 'open',
            'work': work_id,
            'created_by': user_id
        }
        try:
            new_link = vdc_link.add_link(link_info)
            self.assertEqual(new_link, 'You are not here')
        except Exception as e:
            self.assertEqual(
                str(e),
                "Error adding work: 400 - {'message': 'Name is required.'}")

    def test_fail_add_link_no_visibility(self):
        # Get unittest work id
        work_list = vdc_work.get_works(title='unittest_work')
        work_id = work_list[0]['id']
        # Get unittest user id
        user_list = vdc_user.get_users(name='unittest_user')
        user_id = user_list[0]['id']

        link_info = {
            'link': 'unittest_link',
            'name': 'unittest_name',
            # 'visibility': 'open',
            'work': work_id,
            'created_by': user_id
        }
        try:
            new_link = vdc_link.add_link(link_info)
            self.assertEqual(new_link, 'You are not here')
        except Exception as e:
            self.assertEqual(
                str(e),
                "Error adding work: 400 - {'message': 'Visibility is required.'}"
            )

    def test_fail_add_link_no_work(self):
        # Get unittest work id
        # work_list = vdc_work.get_works(title='unittest_work')
        # work_id = work_list[0]['id']
        # Get unittest user id
        user_list = vdc_user.get_users(name='unittest_user')
        user_id = user_list[0]['id']

        link_info = {
            'link': 'unittest_link',
            'name': 'unittest_name',
            'visibility': 'open',
            # 'work': work_id,
            'created_by': user_id
        }
        try:
            new_link = vdc_link.add_link(link_info)
            self.assertEqual(new_link, 'You are not here')
        except Exception as e:
            self.assertEqual(
                str(e),
                "Error adding work: 400 - {'message': 'Work ID is required.'}")

    def test_fail_add_link_no_created_by(self):
        # Get unittest work id
        work_list = vdc_work.get_works(title='unittest_work')
        work_id = work_list[0]['id']
        # Get unittest user id
        # user_list = vdc_user.get_users(name='unittest_user')
        # user_id = user_list[0]['id']

        link_info = {
            'link': 'unittest_link',
            'name': 'unittest_name',
            'visibility': 'open',
            'work': work_id,
            # 'created_by': user_id
        }
        try:
            new_link = vdc_link.add_link(link_info)
            self.assertEqual(new_link, 'You are not here')
        except Exception as e:
            self.assertEqual(
                str(e),
                "Error adding work: 400 - {'message': 'Depositor ID " + \
                "(created_by) is required.'}"
            )

    def tearDown(self):
        link_util.delete_unittest_links()
        work_util.delete_unittest_works()
        project_util.delete_unittest_project()
        user_util.delete_unittest_users()
